# kusu | Kieran's Useful Script Utilities

install using:
`pip install kusu`

or download the source with:
`git clone https://github.com/Descent098/kusu`

There is inline documentation and 

# Official Documentation
There is some readthedocs documentation with examples available at:

__*comming soon*__